@@ -1,7 +1,7 @@
 <?
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balanceview.php,v 1.2 2004/06/16 08:29:57 alec Exp $
+ *  $Id: balanceview.php,v 1.4 2004/09/18 19:21:11 alec Exp $
  */
 
-include_once("class.php");
+include_once('class.php');
 
 $loginform = $_POST[loginform];
 $login = $loginform[login];
@@ -32,12 +32,12 @@ $passwd = $loginform[pwd];
 
 $id = $LMS->DB->GetOne('SELECT id FROM users WHERE phone1 = ? AND pin = ?', array($login, $passwd));
 
-$SMARTY->assign("user",$LMS->GetUser($id));
-$SMARTY->assign("userinfo",$LMS->GetUser($id));
-$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($id));
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("limit",15);
+$SMARTY->assign('user',$LMS->GetUser($id));
+$SMARTY->assign('userinfo',$LMS->GetUser($id));
+$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($id));
+$SMARTY->assign('layout',$layout);
+$SMARTY->assign('limit',15);
 
-$SMARTY->display("balanceview.html");
+$SMARTY->display('balanceview.html');
 
 ?>
