@@ -1,6 +1,7 @@
 <?php 
+
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -20,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: index.php,v 1.3 2004/06/16 08:29:57 alec Exp $
+ *  $Id: index.php,v 1.5 2004/09/18 19:21:11 alec Exp $
  */
 
-include_once("class.php");
+include_once('class.php');
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
 <html><head>
