@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: initLMS.php,v 1.2 2004/02/18 12:49:21 lukasz Exp $
+ *  $Id: initLMS.php,v 1.4 2004/09/18 19:21:11 alec Exp $
  */
 
 /*
@@ -33,43 +33,51 @@
 
 $CONFIG_FILE = (is_readable('lms.ini')) ? 'lms.ini' : '/etc/lms/lms.ini';
 
-// Funkcja do parsowania pliku konfiguracyjnego - niekoniecznie wymagana,
-// ale przydatna
+// Funkcja parsujca plik konfiguracyjny
 
-function lms_parse_ini_file($filename, $process_sections = false)
+function lms_parse_ini_file($filename, $process_sections = false) 
 {
-        $ini_array = array();
-        $sec_name = "";
-        $lines = file($filename);
-        foreach($lines as $line)
-        {
-                $line = trim($line);
-
-                if($line == "" || $line[0] == ";" || $line[0] == "#")
-                        continue;
-
-                if( sscanf($line, "[%[^]]", &$sec_name)==1 )
-                        $sec_name = trim($sec_name);
-                else
-                {
-                        if ( sscanf($line, "%[^=] = '%[^']'", &$property, &$value) != 2 )
-                                if ( sscanf($line, "%[^=] = \"%[^\"]\"", &$property, &$value) != 2 )
-                                        if( sscanf($line, "%[^=] = %[^;#]",    &$property, &$value) != 2 )
-                                                continue;
-                                        else
-                                                $value = trim($value, "\"'");
-
-                        $property = trim($property);
-                        $value = trim($value);
-
-                        if($process_sections)
-                                $ini_array[$sec_name][$property] = $value;
-                        else
-                                $ini_array[$property] = $value;
-                }
-        }
-
-        return $ini_array;
+	$ini_array = array();
+	$section = '';
+	$lines = file($filename);
+	foreach($lines as $line) 
+	{
+		$line = trim($line);
+		
+		if($line == '' || $line[0] == ';' || $line[0] == '#') 
+			continue;
+		
+		list($sec_name) = sscanf($line, "[%[^]]");
+		
+		if( $sec_name )
+			$section = trim($sec_name);
+		else 
+		{
+			list($property, $value) = sscanf($line, "%[^=] = '%[^']'");
+			if ( !$property || !$value ) 
+			{
+				list($property, $value) = sscanf($line, "%[^=] = \"%[^\"]\"");
+				if ( !$property || !$value ) 
+				{
+					list($property, $value) = sscanf($line, "%[^=] = %[^;#]");
+					if( !$property || !$value ) 
+						continue;
+					else
+						$value = trim($value, "\"'");
+				}
+			}
+		
+			$property = trim($property);
+			$value = trim($value);
+			
+			if($process_sections) 
+				$ini_array[$section][$property] = $value;
+			else 
+				$ini_array[$property] = $value;
+		}
+	}
+	
+	return $ini_array;
 }
 
 // Funkcja do sprawdzania wartoci logicznych z configa.
@@ -86,6 +94,11 @@ function chkconfig($value, $default = FALSE)
                 trigger_error('Bdna warto opcji "'.$value.'"');
 }
 
+// Odczytanie pliku konfiguracyjnego
+
+foreach(lms_parse_ini_file($CONFIG_FILE, true) as $key => $val)
+	$_CONFIG[$key] = $val;
+
 // Domylne wartoci zmiennych ktrych nie da si gdzie indziej zdefiniowa.
 
 $_CONFIG['directories']['sys_dir'] = (! $_CONFIG['directories']['sys_dir'] ? getcwd() : $_CONFIG['directories']['sys_dir']);
