@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: sql.php,v 1.6 2004/04/12 19:24:25 alec Exp $
+ *  $Id: sql.php,v 1.8 2004/09/18 19:21:12 alec Exp $
  */
  
 $layout['pagetitle'] = 'SQL';
@@ -84,7 +84,7 @@ if($query = $_POST['query'])
 				$result .= '<TR CLASS="LIGHT"><TD CLASS="BLEND">'.$i.'</TD>';
 				foreach($colnames as $column)	
 				{
-					$result .= '<TD>'.$row[$column].'</TD>';
+					$result .= '<TD>'.nl2br(htmlspecialchars($row[$column])).'</TD>';
 				}
 				$result .= '</TR>';
 			}
