@@ -1,5 +1,5 @@
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dns.c,v 1.7 2004/02/18 12:49:22 lukasz Exp $
+ *  $Id: dns.c,v 1.9 2004/09/18 19:21:12 alec Exp $
  */
 
 #include <stdio.h>
@@ -90,31 +90,97 @@ int write_file(unsigned char *name, unsigned char *text)
 
 void reload(GLOBAL *g, struct dns_module *dns)
 {
-	QUERY_HANDLE *res;
 	unsigned char *configfile = 0;
 	unsigned char *configentries = strdup("");
-	
+	QUERY_HANDLE *res, *res1;
+	int i, j, m, k=2, gc=0, nc=0, nh=0, n=2;
 	struct hostcache
 	{
 		unsigned char *name;
 		unsigned char *mac;
 		unsigned long ipaddr;
 	} *hosts = NULL;
-	int i, nh = 0;
 
-	if ( (res = g->db_query("SELECT name, mac, ipaddr FROM nodes ORDER BY name"))!=NULL ) {
-	
+	struct net *nets = (struct net *) malloc(sizeof(struct net));
+	char *netnames = strdup(dns->networks);	
+	char *netname = strdup(netnames);
+    
+	struct group *ugps = (struct group *) malloc(sizeof(struct group));
+	char *groupnames = strdup(dns->usergroups);	
+	char *groupname = strdup(groupnames);
+
+	while( n>1 ) {
+		
+    		n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
+
+		if( strlen(netname) )
+
+		        if( (res = g->db_pquery("SELECT name, address, INET_ATON(mask) AS mask  FROM networks WHERE UPPER(name)=UPPER('?')",netname))!=NULL) {
+
+				if(res->nrows) {
+					nets = (struct net *) realloc(nets, (sizeof(struct net) * (nc+1)));
+					nets[nc].name = strdup(g->db_get_data(res,0,"name"));
+					nets[nc].address = inet_addr(g->db_get_data(res,0,"address"));
+					nc++;
+				}
+	    			g->db_free(res);
+			}				
+	}
+	free(netname); free(netnames);
+
+	while( k>1 ) {
+		
+		k = sscanf(groupnames, "%s %[._a-zA-Z0-9- ]", groupname, groupnames);
+
+		if( strlen(groupname) ) {
+
+			if( (res = g->db_pquery("SELECT name, id FROM usergroups WHERE UPPER(name)=UPPER('?')",groupname))!=NULL) {
+
+				if(res->nrows) {
+
+			    		ugps = (struct group *) realloc(ugps, (sizeof(struct group) * (gc+1)));
+					ugps[gc].name = strdup(g->db_get_data(res,0,"name"));
+					ugps[gc].id = atoi(g->db_get_data(res,0,"id"));
+					gc++;
+				}
+	    			g->db_free(res);
+			}		
+		}		
+	}
+	free(groupname); free(groupnames);
+
+	if( (res = g->db_query("SELECT name, mac, ipaddr, ownerid FROM nodes ORDER BY ipaddr"))!=NULL ) {
+
 		for(i=0; i<res->nrows; i++) {
-			
-			unsigned char *name, *mac, *ipaddr;
-			
-			name = g->db_get_data(res,i,"name");
-			mac = g->db_get_data(res,i,"mac");
-			ipaddr = g->db_get_data(res,i,"ipaddr");
-			
+				
+			int ownerid = atoi(g->db_get_data(res,i,"ownerid"));
+			unsigned char *name = g->db_get_data(res,i,"name");
+			char *mac = g->db_get_data(res,i,"mac");
+			char *ipaddr = g->db_get_data(res,i,"ipaddr");
+		
 			if(name && mac && ipaddr) {
+
+				// groups test
+				if(gc) {
+					if(ownerid==0)
+						continue;
+					m = gc;
+					if( res1 = g->db_pquery("SELECT usergroupid FROM userassignments WHERE userid=?", g->db_get_data(res,i,"ownerid"))) {
+						for(k=0; k<res1->nrows; k++) {
+							int groupid = atoi(g->db_get_data(res1, k, "usergroupid"));
+							for(m=0; m<gc; m++) 
+								if(ugps[m].id==groupid) 
+									break;
+							if(m!=gc) break;
+						}
+						g->db_free(res1);
+					}
+					if(m==gc)
+						continue;
+				}
+			
 				hosts = (struct hostcache*) realloc(hosts, sizeof(struct hostcache) * (nh + 1));
-				hosts[nh].name = strdup(g->str_lwc(name));
+				hosts[nh].name = strdup(name);
 				hosts[nh].mac = strdup(mac);
 				hosts[nh].ipaddr = inet_addr(ipaddr);
 				nh++;
@@ -135,7 +201,19 @@ void reload(GLOBAL *g, struct dns_module *dns)
 			d = g->db_get_data(res,i,"mask");
 			name = g->db_get_data(res,i,"domain");
 			dnsserv = g->db_get_data(res,i,"dns");
-		
+
+			network = inet_addr(e);
+			netmask = inet_addr(d);
+				
+			// networks test
+			if(nc) {
+				for(j=0; j<nc; j++)
+					if(nets[j].address==network) 
+						break;
+				if(j==nc)
+					continue;
+			}
+
 			if ( d && e && name ) {
 				int prefixlen; // in bytes! 
 				unsigned char *finfile, *ftmpfile;
@@ -151,17 +229,11 @@ void reload(GLOBAL *g, struct dns_module *dns)
 					unsigned char *forwardhosts = strdup("");
 					unsigned char *reversehosts = strdup("");
 				
-					int j;
-				
-					network = inet_addr(e);
-					netmask = inet_addr(d);
-
 					host_netmask = ntohl(netmask);
 					prefixlen = 1; // in bytes! 
 					if(host_netmask & 0x0001ffff) prefixlen = 2;
 					if(host_netmask & 0x000001ff) prefixlen = 3;
 
-
 					finfile = dns->fpatterns;//strdup
 					rinfile = dns->rpatterns;//strdup
 
@@ -201,7 +273,7 @@ void reload(GLOBAL *g, struct dns_module *dns)
 							unsigned char *tmphosts;
 							unsigned long ip;
 						
-							if( (hosts[i].ipaddr & netmask) == network) {
+							if( (hosts[j].ipaddr & netmask) == network) {
 								forwardhost = strdup(dns->forward);
 								reversehost = strdup(dns->reverse);
 					
@@ -336,12 +408,21 @@ void reload(GLOBAL *g, struct dns_module *dns)
 		}
 		g->db_free(res);
 	}
-	
+
+	//cleanup	
 	for(i = 0; i<nh; i++) {
 		free(hosts[i].name);
 		free(hosts[i].mac);
 	}
 	free(hosts);
+
+	for(i=0;i<nc;i++)
+		free(nets[i].name);
+	free(nets);
+	
+	for(i=0;i<gc;i++)
+		free(ugps[i].name);
+	free(ugps);
 	
 	if(configfile) {
 		g->str_replace(&configfile, "%z", configentries);
@@ -370,6 +451,9 @@ void reload(GLOBAL *g, struct dns_module *dns)
 	free(dns->confout);
 	free(dns->confforward);
 	free(dns->confreverse);
+	free(dns->networks);
+	free(dns->usergroups);
+
 }
 
 struct dns_module * init(GLOBAL *g, MODULE *m)
@@ -417,6 +501,11 @@ struct dns_module * init(GLOBAL *g, MODULE *m)
 	dns->confforward = strdup(g->iniparser_getstring(ini, s, "zone \"%n\" {\ntype master;\nfile \"forward/%n\";\nnotify yes;\n};\n"));
 	free(s); s = g->str_concat(instance, ":conf-reverse-entry");
 	dns->confreverse = strdup(g->iniparser_getstring(ini, s, "zone \"%c.in-addr.arpa\" {\ntype master;\nfile \"reverse/%i\";\nnotify yes;\n};\n"));
+	free(s); s = g->str_concat(instance, ":networks");
+	dns->networks = strdup(g->iniparser_getstring(ini, s, ""));
+	free(s); s = g->str_concat(instance, ":usergroups");
+	dns->usergroups = strdup(g->iniparser_getstring(ini, s, ""));
+
 
 	g->iniparser_freedict(ini);
 	free(instance);
@@ -426,4 +515,3 @@ struct dns_module * init(GLOBAL *g, MODULE *m)
 #endif	
 	return (dns);
 }
-
