@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.5.0 Marduk
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_postgres.class.php,v 1.12 2003/10/11 03:45:20 lukasz Exp $
+ *  $Id: LMSDB_driver_postgres.class.php,v 1.19 2004/09/18 19:21:17 alec Exp $
  */
 
 /*
@@ -35,10 +35,16 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function LMSDB_driver_postgres($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.12 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.19 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
+	function _driver_dbversion()
+	{
+		list($var1, $var2) = explode(' ',$this->GetOne("SELECT version()"));
+		return $var2;
+	}
+
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
 		$cstring = join(' ',array(
@@ -53,27 +59,30 @@ class LMSDB_driver_postgres extends LMSDB_common
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
 			$this->_dbname = $dbname;
-			return $this->_dblink;
+			$this->_error = FALSE;
 		}
 		else
-			return FALSE;
+			$this->_error = TRUE;
+		return $this->_dblink;
 	}
 
 	function _driver_disconnect()
 	{
 		return pg_close($this->_dblink);
 	}
+
+	function _driver_geterror()
+	{
+		return pg_last_error($this->_dblink);
+	}
 	
 	function _driver_execute($query)
 	{
+		$this->_query = $query;
 		if($this->_result = pg_query($this->_dblink,$query))
-		{
-			$this->_query = $query;
 			$this->_error = FALSE;
-		}
 		else
-			$this->_error = pg_last_error($this->_dblink);
-
+			$this->_error = TRUE;
 		return $this->_result;
 	}
 
@@ -133,46 +142,4 @@ class LMSDB_driver_postgres extends LMSDB_common
 	}
 }
 
-/* 
- * $Log: LMSDB_driver_postgres.class.php,v $
- * Revision 1.12  2003/10/11 03:45:20  lukasz
- * - http://lists.rulez.pl/lms/1242.html
- *
- * Revision 1.11  2003/09/12 22:22:52  alec
- * Execute zwraca ilo zmodyfikowanych wierszy dla zapyta UPDATE, DELETE, INSERT
- *
- * Revision 1.10  2003/09/10 20:17:17  alec
- * fatal error in postgres disconnect()
- *
- * Revision 1.9  2003/09/10 00:16:19  lukasz
- * - LMSDB::Destroy();
- *
- * Revision 1.8  2003/08/28 21:07:33  lukasz
- * - added support for transactions
- *
- * Revision 1.7  2003/08/25 15:59:12  alec
- * Poprawka na nowsze wersje postgresa
- *
- * Revision 1.6  2003/08/24 14:06:35  lukasz
- * - fixed bug #0000061 - added missing param for pg_fetch_array (but it's
- *   propably only workarround)
- *
- * Revision 1.5  2003/08/24 13:55:16  lukasz
- * - fix with local socket connection
- *
- * Revision 1.4  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.3  2003/08/22 18:03:57  lukasz
- * - added _driver_listtables()
- *
- * Revision 1.2  2003/08/22 13:16:23  lukasz
- * - fixed _driver_concat() (PG uses '||' not '+' as concat sign)
- *
- * Revision 1.1  2003/08/19 01:00:13  lukasz
- * - untested driver for pgsql
- *
- */
-
 ?>
