@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,11 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_sqlite.class.php,v 1.5 2004/04/13 05:40:21 alec Exp $
- */
-
-/*
- To jest eksperymentalny pseudo-driver LMSDB dla bazy danych 'sqlite'.
+ *  $Id: LMSDB_driver_sqlite.class.php,v 1.7 2004/09/18 19:21:17 alec Exp $
  */
 
 class LMSDB_driver_sqlite extends LMSDB_common
@@ -35,7 +31,7 @@ class LMSDB_driver_sqlite extends LMSDB_common
 
 	function LMSDB_driver_sqlite($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.5 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.7 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
@@ -145,6 +141,7 @@ class LMSDB_driver_sqlite extends LMSDB_common
 		sqlite_create_function($this->_dblink, 'upper','strtoupper',1);
 		sqlite_create_function($this->_dblink, 'lower','strtolower',1);
 		sqlite_create_function($this->_dblink, 'floor','floor',1);
+		sqlite_create_function($this->_dblink, 'random','sql_random');
 	}
 }
 
