@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.62 2004/07/28 06:32:35 alec Exp $
+ *  $Id: common.php,v 1.64 2004/09/18 19:21:18 alec Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -889,4 +889,8 @@ function getdir($pwd = './', $pattern = '^.*$')
 	return $files;
 }
 
+function sql_random()
+{
+	return ( rand()/getrandmax() );
+}
 ?>
