@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,12 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.19 2004/04/08 15:21:59 chilek Exp $
+ *  $Id: balancenew.php,v 1.21 2004/09/18 19:21:24 alec Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
 $layout['pagetitle'] = "Nowa operacja finansowa";
+$SMARTY->assign('operation',$_SESSION['addtype']);
 $SMARTY->assign('comment',$_SESSION['addbc']);
 $SMARTY->assign('taxvalue', $_SESSION['addbtax']);
 $SMARTY->assign('time', $_SESSION['addbt']);
