@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: genfake.php,v 1.19 2004/08/16 11:23:19 lexx Exp $
+ *  $Id: genfake.php,v 1.23 2004/09/18 19:21:25 alec Exp $
  */
 
 // Nazwiska
@@ -1561,6 +1561,7 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 		$useradd['serviceaddr'] = '';
 		$useradd['info'] = '';
 		$useradd['message'] = '';
+		$useradd['pin'] = rand(10000,99999);
 		$id = $LMS->UserAdd($useradd);
 		$LMS->AddAssignMent(array( 'tariffid' => $useradd['tariff'], 'userid' => $id, 'period' => 1, 'at' => $useradd['payday'], 'invoice' => 0, 'datefrom' => 0, 'dateto' => 0));
 		$nodes = mt_rand(1,3);
@@ -1574,8 +1575,8 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 			$nodedata['ownerid'] = $id;
 			$nodedata['access'] = 1;
 			$nodedata['warning'] = 0;
-			$nodeid = $LMS->NodeAdd($nodedata);
-			$DB->Execute("UPDATE `nodes` SET `lastonline` = '".mt_rand(time()-2592000,time()+2592000)."' WHERE `id` = '".$nodeid."' ");
+			if($nodeid = $LMS->NodeAdd($nodedata))
+				$DB->Execute('UPDATE nodes SET lastonline=? WHERE id=? ', array(mt_rand(time()-2592000,time()+2592000),$nodeid));
 		}
 		$startip ++;
 	}
