@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenew.php,v 1.11 2004/04/13 09:21:24 alec Exp $
+ *  $Id: invoicenew.php,v 1.13 2004/09/18 19:21:26 alec Exp $
  */
 
 $layout['pagetitle'] = 'Nowa faktura';
@@ -39,8 +39,8 @@ switch($_GET['action'])
 {
 	case 'additem':
 		$itemdata = r_trim($_POST);
-		foreach(array('count', 'valuenetto', 'valuebrutto') as $key)			
-			$itemdata[$key] = sprintf('%01.2f',$itemdata[$key]);
+		foreach(array('count', 'valuenetto', 'valuebrutto') as $key)
+			$itemdata[$key] = sprintf('%01.2f', str_replace(',','.',$itemdata[$key]));
 		if ($itemdata['taxvalue'] != '')
 			$itemdata['taxvalue'] = sprintf('%01.2f',$itemdata['taxvalue']);
 		if($itemdata['count'] > 0 && $itemdata['name'] != '')
