@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netadd.php,v 1.32 2004/08/31 06:44:50 lukasz Exp $
+ *  $Id: netadd.php,v 1.34 2004/09/18 19:21:26 alec Exp $
  */
 
 $netadd = $_POST['netadd'];
@@ -49,7 +49,7 @@ if(isset($netadd))
 
 	if($netadd['name'] == '')
 		$error['name'] = 'Musisz poda nazw sieci!';
-	elseif(!eregi('^[.a-z0-9-]+$', $netadd['name']))
+	elseif(!eregi('^[._a-z0-9-]+$', $netadd['name']))
 		$error['name'] = 'Podana nazwa sieci zawiera niepoprawne znaki!';
 	
 	if($netadd['domain'] != '' && !eregi('^[.a-z0-9-]+$', $netadd['domain']))
