@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevadd.php,v 1.8 2004/03/15 14:08:41 alec Exp $
+ *  $Id: netdevadd.php,v 1.10 2004/09/18 19:21:26 alec Exp $
  */
 
 $netdevdata = $_POST['netdev'];
@@ -34,6 +34,8 @@ if(isset($netdevdata)) {
 		$netdevdata['ports'] = 0;
 	if($netdevdata['name'] == '')
 		$error['name'] = 'Pole nazwa nie moe by puste!';
+	elseif(strlen($netdevdata['name'])>32)
+		$error['name'] = 'Podana nazwa jest za duga!';
 
         if(!$error)
         {
