@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.26 2004/08/25 19:31:12 alec Exp $
+ *  $Id: netdevmap.php,v 1.30 2004/09/18 19:21:26 alec Exp $
  */
 
 function drawtext($image, $font, $x, $y, $text, $color, $bgcolor)
@@ -44,13 +44,21 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 	$fields[] = array( 'x' => -5, 'y' => 0 );
 	$fields[] = array( 'x' => -5, 'y' => 5 );
 	$fields[] = array( 'x' => 5, 'y' => 10 );
-	$fields[] = array( 'x' => 10, 'y' => 10 );     
-	$fields[] = array( 'x' => 10, 'y' => 5 );
-	$fields[] = array( 'x' => 10, 'y' => -10 );
 	$fields[] = array( 'x' => 5, 'y' => -10 );
-	$fields[] = array( 'x' => -10, 'y' => -10 );
+	$fields[] = array( 'x' => -5, 'y' => 10 );
+	$fields[] = array( 'x' => -5, 'y' => -10 );
+	$fields[] = array( 'x' => 10, 'y' => 5 );
+	$fields[] = array( 'x' => 10, 'y' => -5 );
 	$fields[] = array( 'x' => -10, 'y' => 5 );
-	$fields[] = array( 'x' => -10, 'y' => 10 );
+	$fields[] = array( 'x' => -10, 'y' => -5 );
+	$fields[] = array( 'x' => 5, 'y' => 15 );
+	$fields[] = array( 'x' => 5, 'y' => -15 );
+	$fields[] = array( 'x' => -5, 'y' => 15 );
+	$fields[] = array( 'x' => -5, 'y' => -15 );
+	$fields[] = array( 'x' => 10, 'y' => 15 );
+	$fields[] = array( 'x' => 10, 'y' => -15 );
+	$fields[] = array( 'x' => -10, 'y' => 15 );
+	$fields[] = array( 'x' => -10, 'y' => -15 );
 
 	unset($nodefields);
 
@@ -169,7 +177,7 @@ if($_GET['graph'] == "")
 	$widthy = $maxy - $miny;
 	$cellw = 70;
 	$cellh = 30;
-	$celltmargin = 10;
+	$celltmargin = 20;
 	$celllmargin = 10;
 	$imgwx = $cellw * ($widthx + 2);
 	$imgwy = $cellh * ($widthy + 2);
@@ -196,7 +204,7 @@ if($_GET['graph'] == "")
 			}
 		}
 	}
-	sort($nodemap);
+	if(sizeof($nodemap)) sort($nodemap);
 	sort($devicemap);
 
 	$SMARTY->assign('devicemap',$devicemap);
@@ -235,7 +243,7 @@ else
 	$widthy = $maxy - $miny;
 	$cellw = 70;
 	$cellh = 30;
-	$celltmargin = 10;
+	$celltmargin = 20;
 	$celllmargin = 10;
 	$imgwx = $cellw * ($widthx + 2);
 	$imgwy = $cellh * ($widthy + 2);
@@ -288,7 +296,7 @@ else
 		imageline($im, $src_px+9, $src_py+9, $dst_px+9, $dst_py+9, $green);
 	}
 
-	foreach($nodemap as $node)
+	if($nodemap) foreach($nodemap as $node)
 	{
 		$src_celx = $node['x'];
 		$src_cely = $node['y'];
@@ -301,12 +309,14 @@ else
 		imageline($im, $src_px+4, $src_py+4, $dst_px+4, $dst_py+4, $red);
 	}
 
-	$im_nd = imagecreatefrompng('img/netdev.png');
 	$im_n_unk = imagecreatefrompng('img/node_unk.png');
 	$im_n_off = imagecreatefrompng('img/node_off.png');
 	$im_n_on = imagecreatefrompng('img/node_on.png');
+	$im_d_unk = imagecreatefrompng('img/netdev_unk.png');
+	$im_d_off = imagecreatefrompng('img/netdev_off.png');
+	$im_d_on = imagecreatefrompng('img/netdev_on.png');
 
-	foreach($nodemap as $nodeid => $node)
+	if($nodemap) foreach($nodemap as $nodeid => $node)
 	{
 		$celx = $node['x'];
 		$cely = $node['y'];
@@ -331,15 +341,24 @@ else
 		$cely = $device['y'];
 		$px = (($celx * ($cellw)) + $celllmargin);
 		$py = (($cely * ($cellh)) + $celltmargin);
-		imagecopy($im,$im_nd,$px,$py,0,0,16,16);
-		$deviceip = $DB->GetCol('SELECT INET_NTOA(ipaddr) FROM nodes WHERE ownerid=0 AND netdev=? ORDER BY ipaddr', array($deviceid));
-		if($deviceip[0]) drawtext($im, 1, $px + 20, $py - ($deviceip[1]?17:8), $deviceip[0], $blue, $lightbrown);
-		if($deviceip[1]) drawtext($im, 1, $px + 20, $py - 8, $deviceip[1], $blue, $lightbrown);
-		if($deviceip[2]) drawtext($im, 1, $px + 20, $py + 17, $deviceip[2], $blue, $lightbrown);
-		if($deviceip[3]) drawtext($im, 1, $px + 20, $py + 26, $deviceip[3], $blue, $lightbrown);
-		drawtext($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $darkred, $lightbrown);
-		$location=$DB->GetOne('SELECT location FROM netdevices WHERE id=?',array($deviceid));
-		drawtext($im, 2, $px + 20, $py + 18, $location, $green, $lightbrown);
+		
+		$lastonline = $DB->GetOne('SELECT MAX(lastonline) FROM nodes WHERE ownerid=0 AND netdev=?', array($deviceid));
+		if ($lastonline) {	
+			if ((time()-$lastonline)>$LMS->CONFIG['phpui']['lastonline_limit'])
+				imagecopy($im,$im_d_off,$px,$py,0,0,15,16);
+			else 
+				imagecopy($im,$im_d_on,$px,$py,0,0,15,16);
+		} else 
+			imagecopy($im,$im_d_unk,$px,$py,0,0,15,16);
+		
+		$devip = $DB->GetCol('SELECT INET_NTOA(ipaddr) FROM nodes WHERE ownerid=0 AND netdev=? ORDER BY ipaddr LIMIT 4', array($deviceid));
+		if($devip[0]) drawtext($im, 1, $px + 20, $py - ($devip[1]?17:8), $devip[0], $blue, $lightbrown);
+		if($devip[1]) drawtext($im, 1, $px + 20, $py - 8, $devip[1], $blue, $lightbrown);
+		if($devip[2]) drawtext($im, 1, $px + 20, $py + 17, $devip[2], $blue, $lightbrown);
+		if($devip[3]) drawtext($im, 1, $px + 20, $py + 26, $devip[3], $blue, $lightbrown);
+		
+		drawtext($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $black, $lightbrown);
+		drawtext($im, 2, $px + 20, $py + 18, $DB->GetOne('SELECT location FROM netdevices WHERE id=?',array($deviceid)), $green, $lightbrown);
 	}
 		
 	imagepng($im);
