@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netedit.php,v 1.30 2004/03/11 17:24:22 lukasz Exp $
+ *  $Id: netedit.php,v 1.32 2004/09/18 19:21:26 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
@@ -89,7 +89,7 @@ if(isset($networkdata))
 
 	if($networkdata['name']=="")
 		$error['name'] = "Musisz poda nazw sieci!";
-	elseif(!eregi("^[.a-z0-9-]+$",$networkdata['name']))
+	elseif(!eregi("^[._a-z0-9-]+$",$networkdata['name']))
 		$error['name'] = "Podana nazwa sieci zawiera nieprawidowe znaki!";
 
 	if($networkdata['domain']!="" && !eregi("^[.a-z0-9-]+$",$networkdata['domain']))
