@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,26 +21,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netinfo.php,v 1.25 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: netinfo.php,v 1.28 2004/09/18 19:21:27 alec Exp $
  */
 
-if(!$LMS->NetworkExists($_GET[id]))
+if(!$LMS->NetworkExists($_GET['id']))
 {
 	header("Location: ?m=netlist");
 	die;
 }
 
-if (isset($_SESSION[ntlp][$_GET[id]]) && !isset($_GET[page]))
-	$_GET[page] = $_SESSION[ntlp][$_GET[id]];
+if (isset($_SESSION['ntlp'][$_GET['id']]) && !isset($_GET['page']))
+	$_GET['page'] = $_SESSION['ntlp'][$_GET['id']];
 
-$_SESSION[ntlp][$_GET[id]] = $_GET[page];
+$_SESSION['ntlp'][$_GET['id']] = $_GET['page'];
 
-$network = $LMS->GetNetworkRecord($_GET[id],$_GET[page],1024);
+$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'],1024);
 
-$layout[pagetitle]="Informacja o sieci: ".$network[name];
+$layout['pagetitle'] = "Informacja o sieci: ".$network['name'];
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("network",$network);
-$SMARTY->display("netinfo.html");
+$SMARTY->assign('network',$network);
+$SMARTY->display('netinfo.html');
 
 ?>
