@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,22 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodescan.php,v 1.13 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: nodescan.php,v 1.16 2004/09/18 19:21:27 alec Exp $
  */
 
-if($_GET[ownerid]&&$LMS->UserExists($_GET[ownerid]))
+if($_GET['ownerid']&&$LMS->UserExists($_GET['ownerid']))
 {
-	$userinfo = $LMS->GetUser($_GET[ownerid]);
+	$userinfo = $LMS->GetUser($_GET['ownerid']);
 }
 
-$layout[pagetitle]="Wyszukiwanie komputerw";
+$layout['pagetitle'] = "Wyszukiwanie komputerw";
 
-$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($_GET[ownerid]));
-$SMARTY->assign("users",$users);
-$SMARTY->assign("nodes",$LMS->ScanNodes());
-$SMARTY->assign("userinfo",$userinfo);
-$SMARTY->assign("layout",$layout);
+$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($_GET['ownerid']));
+$SMARTY->assign('users',$users);
+$SMARTY->assign('nodes',$LMS->ScanNodes());
+$SMARTY->assign('userinfo',$userinfo);
 
-$SMARTY->display("nodescan.html");
+$SMARTY->display('nodescan.html');
 
 ?>
\ No newline at end of file
