@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentinfo.php,v 1.3 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: paymentinfo.php,v 1.6 2004/09/18 19:21:28 alec Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
@@ -34,10 +34,9 @@ $payment = $LMS->GetPayment($_GET['id']);
 
 $layout['pagetitle'] = "Informacja o opacie staej: ".$payment['name'];
 
-$_SESSION['backto'] = $_SERVER[QUERY_STRING];
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("payment",$payment);
-$SMARTY->display("paymentinfo.html");
+$SMARTY->assign('payment',$payment);
+$SMARTY->display('paymentinfo.html');
 
 ?>
