@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffinfo.php,v 1.20 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: tariffinfo.php,v 1.22 2004/09/18 19:21:28 alec Exp $
  */
 
 if(!$LMS->TariffExists($_GET['id']))
@@ -34,7 +34,6 @@ $layout['pagetitle'] = "Informacja o taryfie: ".$tariff['name'];
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('tariff',$tariff);
 $SMARTY->assign('tariffs',$LMS->GetTariffs());
 $SMARTY->display('tariffinfo.html');
