@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useradd.php,v 1.47 2004/03/11 21:06:50 alec Exp $
+ *  $Id: useradd.php,v 1.51 2004/09/18 19:21:29 alec Exp $
  */
 
 $useradd = $_POST['useradd'];
@@ -55,9 +55,15 @@ elseif(isset($useradd))
 
 	if($useradd['gguin'] == '')
 		$useradd['gguin'] = 0;
+	
+	if($useradd['pin'] == '')
+		$useradd['pin'] = 0;
 
 	if($useradd['gguin'] !=0 && !eregi('^[0-9]{4,}$',$useradd['gguin']))
 		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
+
+        if($userdata['pin']!=0 && !eregi('^[0-9]{4,6}$',$useradd['pin']))
+	        $error['pin'] = 'Podany numer PIN jest niepoprawny!';
 	
 	if(!$error)
 	{
