@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.6 Osiris
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useredit.php,v 1.63 2004/07/14 13:28:04 alec Exp $
+ *  $Id: useredit.php,v 1.67 2004/09/18 19:21:29 alec Exp $
  */
 
 $userdata = $_POST['userdata'];
@@ -72,9 +72,15 @@ elseif(isset($userdata))
 	if($userdata['gguin'] == '')
 		$userdata['gguin'] = 0;
 
+	if($userdata['pin'] == '')
+		$userdata['pin'] = 0;
+
 	if($userdata['gguin']!=0 && !eregi('^[0-9]{4,}$',$userdata['gguin']))
 		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
 
+	if($userdata['pin']!=0 && !eregi('^[0-9]{4,6}$',$userdata['pin']))
+		$error['pin'] = 'Podany numer PIN jest niepoprawny!';
+
 	if($userdata['status']!=3&&$LMS->GetUserNodesNo($userdata['id'])) 
 		$error['status'] = 'Tylko podczony uytkownik moe posiada komputery!';
 		
