@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.5.0 Marduk
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,23 +21,22 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.32 2004/02/18 12:49:24 lukasz Exp $
+ *  $Id: welcome.php,v 1.38 2004/09/18 19:21:30 alec Exp $
  */
 
-require_once($_LIB_DIR."/Sysinfo.class.php");
-require_once($_LIB_DIR."/fortunes.php");
+require_once($_LIB_DIR.'/Sysinfo.class.php');
+require_once($_LIB_DIR.'/fortunes.php');
 
 $SI = new Sysinfo;
 
-$layout['pagetitle'] = "LAN Management System";
+$layout['pagetitle'] = 'LAN Management System';
 
 $layout['dbversion'] = $LMS->DB->GetDBVersion();
 $layout['dbtype'] = $LMS->CONFIG['database']['type'];
 
-$SMARTY->assign("sysinfo",$SI->get_sysinfo());
-$SMARTY->assign("userstats",$LMS->UserStats());
-$SMARTY->assign("nodestats",$LMS->NodeStats());
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("welcome.html");
+$SMARTY->assign('sysinfo',$SI->get_sysinfo());
+$SMARTY->assign('userstats',$LMS->UserStats());
+$SMARTY->assign('nodestats',$LMS->NodeStats());
+$SMARTY->display('welcome.html');
 
 ?>
